public inbox for git-commits@fedoraproject.org
help / color / mirror / Atom feed
From: Tom Rix <Tom.Rix@amd.com>
To: git-commits@fedoraproject.org
Subject: [rpms/rocblas] epel10: Update preview to 7.12
Date: Thu, 11 Jun 2026 14:33:13 GMT [thread overview]
Message-ID: <178118839322.1.9123716688535231853.rpms-rocblas-4b2b7a8a0068@fedoraproject.org> (raw)
A new commit has been pushed.
Repo : rpms/rocblas
Branch : epel10
Commit : 4b2b7a8a0068e84050188e6228b97bc2ce05b523
Author : Tom Rix <Tom.Rix@amd.com>
Date : 2026-03-30T05:46:05-07:00
Stats : +72/-73 in 7 file(s)
URL : https://src.fedoraproject.org/rpms/rocblas/c/4b2b7a8a0068e84050188e6228b97bc2ce05b523?branch=epel10
Log:
Update preview to 7.12
Signed-off-by: Tom Rix <Tom.Rix@amd.com>
---
diff --git a/0001-improve-the-warning-for-asm-caps-mismatches.patch b/0001-improve-the-warning-for-asm-caps-mismatches.patch
index 66005bf..84d6312 100644
--- a/0001-improve-the-warning-for-asm-caps-mismatches.patch
+++ b/0001-improve-the-warning-for-asm-caps-mismatches.patch
@@ -1,4 +1,4 @@
-From 22338f7f0aa80c41b04ff4075a9b39957228d219 Mon Sep 17 00:00:00 2001
+From 91d36d8801293fcaf5b0d8c99fad24e9323e73ca Mon Sep 17 00:00:00 2001
From: Tom Rix <Tom.Rix@amd.com>
Date: Sun, 8 Mar 2026 10:48:50 -0700
Subject: [PATCH 1/6] improve the warning for asm caps mismatches
@@ -12,7 +12,7 @@ Signed-off-by: Tom Rix <Tom.Rix@amd.com>
1 file changed, 9 insertions(+)
diff --git a/shared/tensile/Tensile/Common.py b/shared/tensile/Tensile/Common.py
-index a7bbf0724a80..b97fa061327b 100644
+index 8d9cf2771b11..f335bcc34583 100644
--- a/shared/tensile/Tensile/Common.py
+++ b/shared/tensile/Tensile/Common.py
@@ -2010,6 +2010,14 @@ def locateExe( defaultPath, exeName ): # /opt/rocm/bin, hip-clang
diff --git a/0002-add-generic-gpu-targets.patch b/0002-add-generic-gpu-targets.patch
index 68b8e28..e6ec749 100644
--- a/0002-add-generic-gpu-targets.patch
+++ b/0002-add-generic-gpu-targets.patch
@@ -1,4 +1,4 @@
-From 60c8c0786b61e1ab2040f7b6d7b6c2b4b244c9e1 Mon Sep 17 00:00:00 2001
+From 1facb97e3b5ad1570562aff89a0e279155db6c18 Mon Sep 17 00:00:00 2001
From: Tom Rix <Tom.Rix@amd.com>
Date: Sun, 8 Mar 2026 01:32:28 +0000
Subject: [PATCH 2/6] add generic gpu targets
@@ -340,7 +340,7 @@ index 48eeec1f9a6c..58776e249b78 100644
'HasAtomicAdd': False,
'HasDirectToLdsDest': False,
diff --git a/shared/tensile/Tensile/Common.py b/shared/tensile/Tensile/Common.py
-index b97fa061327b..9a2c399fad1b 100644
+index f335bcc34583..89bf6f4aa20f 100644
--- a/shared/tensile/Tensile/Common.py
+++ b/shared/tensile/Tensile/Common.py
@@ -246,12 +246,12 @@ globalParameters["NumMergedFiles"] = 1 # The number of files that ker
@@ -551,7 +551,7 @@ index 1d22bfe712da..be9d5a78c077 100644
{
return static_cast<AMDGPU::Processor>(0);
diff --git a/shared/tensile/Tensile/Source/lib/include/Tensile/PlaceholderLibrary.hpp b/shared/tensile/Tensile/Source/lib/include/Tensile/PlaceholderLibrary.hpp
-index a9da044e8f39..2f8b18779936 100644
+index c164bde1c13f..dcf4af10bda4 100644
--- a/shared/tensile/Tensile/Source/lib/include/Tensile/PlaceholderLibrary.hpp
+++ b/shared/tensile/Tensile/Source/lib/include/Tensile/PlaceholderLibrary.hpp
@@ -66,6 +66,12 @@ namespace Tensile
diff --git a/0003-improve-fallback-name-to-handle-generics.patch b/0003-improve-fallback-name-to-handle-generics.patch
index 68859a0..46b6544 100644
--- a/0003-improve-fallback-name-to-handle-generics.patch
+++ b/0003-improve-fallback-name-to-handle-generics.patch
@@ -1,4 +1,4 @@
-From 6f042a916612aca518254d5870590d15ec7a16e6 Mon Sep 17 00:00:00 2001
+From 9a54945335d17213700a4b08f3e3b1cff8d42906 Mon Sep 17 00:00:00 2001
From: Tom Rix <Tom.Rix@amd.com>
Date: Sun, 8 Mar 2026 13:38:28 -0700
Subject: [PATCH 3/6] improve fallback name to handle generics
diff --git a/0004-generic-arches-need-a-solution-index.patch b/0004-generic-arches-need-a-solution-index.patch
index be1b231..3853b01 100644
--- a/0004-generic-arches-need-a-solution-index.patch
+++ b/0004-generic-arches-need-a-solution-index.patch
@@ -1,4 +1,4 @@
-From 71f280ea73630c0453fda896a36d0b3092b95aed Mon Sep 17 00:00:00 2001
+From 5e411dc64dde73141fd1958c58ec2876ca064b4f Mon Sep 17 00:00:00 2001
From: Tom Rix <Tom.Rix@amd.com>
Date: Sun, 8 Mar 2026 16:21:07 -0700
Subject: [PATCH 4/6] generic arches need a solution index
diff --git a/0005-rocblas-add-rocblas_internal_get_generic_arch_name.patch b/0005-rocblas-add-rocblas_internal_get_generic_arch_name.patch
index 19d3b70..d8f9f85 100644
--- a/0005-rocblas-add-rocblas_internal_get_generic_arch_name.patch
+++ b/0005-rocblas-add-rocblas_internal_get_generic_arch_name.patch
@@ -1,42 +1,44 @@
-From 8926fb0fca00d1ff859682b3df91243cff650425 Mon Sep 17 00:00:00 2001
+From 9e5a358d9251d4770edd74be248b4d3ded705018 Mon Sep 17 00:00:00 2001
From: Tom Rix <Tom.Rix@amd.com>
-Date: Mon, 9 Mar 2026 18:15:43 -0700
-Subject: [PATCH 5/6] [rocblas] add rocblas_internal_get_generic_arch_name
+Date: Sun, 29 Mar 2026 10:48:52 -0700
+Subject: [PATCH 5/6] rocblas add rocblas_internal_get_generic_arch_name
-A function similar to rocblas_internal_get_arch_name,
-returns the generic name for the arch.
-
-Signed-off-by: Tom Rix <Tom.Rix@amd.com>
---
- .../rocblas/library/src/include/utility.hpp | 3 ++
- .../rocblas/library/src/rocblas_auxiliary.cpp | 47 +++++++++++++++++++
- 2 files changed, 50 insertions(+)
+ .../rocblas/library/src/include/utility.hpp | 9 +++
+ .../rocblas/library/src/rocblas_auxiliary.cpp | 55 +++++++++++++++++++
+ 2 files changed, 64 insertions(+)
diff --git a/projects/rocblas/library/src/rocblas_auxiliary.cpp b/projects/rocblas/library/src/rocblas_auxiliary.cpp
-index 57c24a9f519d..3f7c375eefc4 100644
+index 37a4bc5b097c..4524f19ed056 100644
--- a/projects/rocblas/library/src/rocblas_auxiliary.cpp
+++ b/projects/rocblas/library/src/rocblas_auxiliary.cpp
-@@ -917,6 +917,53 @@ bool rocblas_internal_tensile_supports_xdl_math_op(rocblas_math_mode mode)
- return (deviceString.find("gfx942") != std::string::npos);
+@@ -908,6 +908,61 @@ std::string rocblas_internal_get_arch_name()
+ return rocblas_internal_get_arch_name(deviceId);
}
-+std::string rocblas_internal_get_generic_arch_name()
++std::string rocblas_internal_get_generic_arch_name(int deviceId)
+{
-+ std::string arch_name = rocblas_internal_get_arch_name();
++ std::string arch_name = rocblas_internal_get_arch_name(deviceId);
+ // Map specific architecture names to generic names
+ static const std::map<std::string, std::string> arch_map = {
+ {"gfx900", "gfx9-generic"},
@@ -81,8 +83,16 @@ index 57c24a9f519d..3f7c375eefc4 100644
+ // Return original name if no mapping found
+ return arch_name;
+}
- // exported. Get architecture name
- std::string rocblas_internal_get_arch_name()
++
++std::string rocblas_internal_get_generic_arch_name()
++{
++ int deviceId;
++ PRINT_IF_HIP_ERROR(hipGetDevice(&deviceId));
++ return rocblas_internal_get_generic_arch_name(deviceId);
++}
++
+ // exported. Get xnack mode
+ std::string rocblas_internal_get_xnack_mode()
{
--
2.53.0
diff --git a/0006-rocblas-generalize-finding-tensile-for-generics.patch b/0006-rocblas-generalize-finding-tensile-for-generics.patch
index d8be7e8..b7fd693 100644
--- a/0006-rocblas-generalize-finding-tensile-for-generics.patch
+++ b/0006-rocblas-generalize-finding-tensile-for-generics.patch
@@ -1,36 +1,28 @@
-From 4bf4de5e52725e5d253eef646d770004ef9db772 Mon Sep 17 00:00:00 2001
+From 451b914cba95faacd1d37e179b4869b16ad53c16 Mon Sep 17 00:00:00 2001
From: Tom Rix <Tom.Rix@amd.com>
-Date: Tue, 10 Mar 2026 07:06:47 -0700
-Subject: [PATCH 6/6] [rocblas] generalize finding tensile for generics
+Date: Sun, 29 Mar 2026 11:03:43 -0700
+Subject: [PATCH 6/6] rocblas generalize finding tensile for generics
-If rocblas is built with ex/ gfx11-generic it should run on any
-gfx11XX gpu. So when finding the tensile library, check first
-the specific gpu, then the generic gpu.
-
-Signed-off-by: Tom Rix <Tom.Rix@amd.com>
---
- projects/rocblas/library/src/tensile_host.cpp | 85 ++++++++++---------
- 1 file changed, 47 insertions(+), 38 deletions(-)
+ projects/rocblas/library/src/tensile_host.cpp | 78 +++++++++++--------
+ 1 file changed, 45 insertions(+), 33 deletions(-)
diff --git a/projects/rocblas/library/src/tensile_host.cpp b/projects/rocblas/library/src/tensile_host.cpp
-index 1c9012f5d192..4587d498f94e 100644
+index 45a7dab90ae6..f72e717c0581 100644
--- a/projects/rocblas/library/src/tensile_host.cpp
+++ b/projects/rocblas/library/src/tensile_host.cpp
-@@ -720,7 +720,10 @@ namespace
+@@ -792,63 +792,75 @@ namespace
#endif
// The name of the current GPU platform
-- std::string processor = rocblas_internal_get_arch_name();
-+ std::string specific_processor = rocblas_internal_get_arch_name();
-+ std::string generic_processor = rocblas_internal_get_generic_arch_name();
+- std::string processor = rocblas_internal_get_arch_name(deviceId);
++ std::string specific_processor = rocblas_internal_get_arch_name(deviceId);
++ std::string generic_processor = rocblas_internal_get_generic_arch_name(deviceId);
+ std::string processors[2] = {specific_processor, generic_processor};
+ std::string processor;
- // Get current xnack mode
- std::string xnack = rocblas_internal_get_xnack_mode();
-@@ -806,59 +809,65 @@ namespace
- return 0;
- }();
+ static std::string base_path;
+ static int determined_path = determine_tensile_base_path(base_path);
- path = base_path;
- if(TestPath(path + "/" + processor))
@@ -54,22 +46,21 @@ index 1c9012f5d192..4587d498f94e 100644
#endif
- if(!TestPath(tensileLibraryPath))
- {
--
+- tensile_lazy_load_enabled = false;
+ if(TestPath(tensileLibraryPath)) {
-+ tensile_lazy_load_enabled = true;
-+ break;
++ tensile_lazy_load_enabled = true;
++ break;
+ }
+
#ifdef TENSILE_YAML
-- tensileLibraryPath = path + "/TensileLibrary_" + processor + ".yaml";
-+ tensileLibraryPath = path + "/TensileLibrary_" + processor + ".yaml";
+ tensileLibraryPath = path + "/TensileLibrary_" + processor + ".yaml";
#else
-- tensileLibraryPath = path + "/TensileLibrary_" + processor + ".dat";
-+ tensileLibraryPath = path + "/TensileLibrary_" + processor + ".dat";
+ tensileLibraryPath = path + "/TensileLibrary_" + processor + ".dat";
#endif
- if(!TestPath(tensileLibraryPath))
- {
+ if(TestPath(tensileLibraryPath))
-+ break;
++ break;
+
#ifdef TENSILE_YAML
- tensileLibraryPath = path + "/TensileLibrary.yaml";
@@ -81,7 +72,7 @@ index 1c9012f5d192..4587d498f94e 100644
- if(!TestPath(tensileLibraryPath))
- {
+ if(TestPath(tensileLibraryPath))
-+ break;
++ break;
+
#if ROCBLAS_TENSILE_SEPARATE_ARCH
- rocblas_cerr << "\nrocBLAS error: Cannot read " << tensileLibraryPath
@@ -102,17 +93,16 @@ index 1c9012f5d192..4587d498f94e 100644
- {
- if(std::regex_match(file_name.path().string(), fileMatcher))
- {
-- rocblas_cerr << file_name << std::endl;
-- }
-- }
+ rocblas_cerr << " List of available TensileLibrary Files : " << std::endl;
+ for(auto& file_name : fs::directory_iterator(path))
-+ {
-+ if(std::regex_match(file_name.path().string(), fileMatcher))
-+ {
-+ rocblas_cerr << file_name << std::endl;
-+ }
-+ }
++ {
++ if(std::regex_match(file_name.path().string(), fileMatcher))
++ {
+ rocblas_cerr << file_name << std::endl;
+- }
+- }
++ }
++ }
#else
- rocblas_cerr << "\nrocBLAS error: Cannot read " << tensileLibraryPath
- << ": " << strerror(errno) << std::endl;
@@ -123,13 +113,12 @@ index 1c9012f5d192..4587d498f94e 100644
- }
- }
- }
-- else
-- tensile_lazy_load_enabled = true;
++
+ if (i == 1)
-+ rocblas_abort();
++ rocblas_abort();
+ }
- //Supports multi architecture configuration in lazy library loading mode
+ // Supports multi architecture configuration
static int initialize_once = [&] {
--
2.53.0
diff --git a/rocblas.spec b/rocblas.spec
index a4a1c56..f2610ba 100644
--- a/rocblas.spec
+++ b/rocblas.spec
@@ -23,7 +23,7 @@
%bcond_with preview
%if %{with preview}
-%global rocm_release 7.11
+%global rocm_release 7.12
%global rocm_patch 0
%global pkg_src therock-%{rocm_release}
%else
reply other threads:[~2026-06-11 14:33 UTC|newest]
Thread overview: [no followups] expand[flat|nested] mbox.gz Atom feed
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=178118839322.1.9123716688535231853.rpms-rocblas-4b2b7a8a0068@fedoraproject.org \
--to=tom.rix@amd.com \
--cc=git-commits@fedoraproject.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
diff --git a/projects/rocblas/library/src/include/utility.hpp b/projects/rocblas/library/src/include/utility.hpp
-index bb4212f78630..966958c9aca4 100644
+index 092df38d8930..73aeb9e908e4 100644
--- a/projects/rocblas/library/src/include/utility.hpp
+++ b/projects/rocblas/library/src/include/utility.hpp
-@@ -800,6 +800,9 @@ bool rocblas_internal_tensile_supports_ldc_ne_ldd(rocblas_handle handle);
- // We assume true if the value is between 942 to 1000
- ROCBLAS_INTERNAL_EXPORT bool rocblas_internal_tensile_supports_xdl_math_op(rocblas_math_mode mode);
+@@ -806,6 +806,15 @@ std::string rocblas_internal_get_arch_name(int device);
+ // for internal use during testing, fetch arch name
+ ROCBLAS_INTERNAL_EXPORT std::string rocblas_internal_get_arch_name();
+// for internal use
++std::string rocblas_internal_get_arch_name(int device);
++
++// for internal use
+ROCBLAS_INTERNAL_EXPORT std::string rocblas_internal_get_generic_arch_name();
+
- // for internal use during testing, fetch arch name
- ROCBLAS_INTERNAL_EXPORT std::string rocblas_internal_get_arch_name();
++// for internal use
++std::string rocblas_internal_get_generic_arch_name(int device);
++
+ // for internal use, fetch xnack mode
+ std::string rocblas_internal_get_xnack_mode();